Usage — VRProt 0.0.7 documentation

# Usage

## Installation

To use VRProt in your project, you can install it from PyPI using pip:

Install the package e.g. in a virtual environment:

1. create a virtual environment
   `python3 -m venv name_of_env`

2. activate it
   `source name_of_env/bin/activate`

3. install requirements packages
   `python3 -m pip install -r requirements.txt` TODO: Skip when pyproject is complete

   3.1. under mac you might have to install the following packages
   `brew install libomp`

4. install VRProt
   `pip install VRProt`